package query

import (
	"context"
	"gd_adm_data/apis"
	"gd_adm_data/errors"

	jsoniter "github.com/json-iterator/go"

	"gorm.io/gorm"

	"git.getensh.com/common/gopkgsv2/database"
	"git.getensh.com/common/gopkgsv2/logger"
	"go.uber.org/zap"
)

type a02Req struct {
	Vin       string `json:"vin"`
	PlateType string `json:"plate_type"`
}

// vin查车辆信息
func A02(ctx context.Context, params string) (reply *apis.QueryResponse, err error) {
	reply = &apis.QueryResponse{}

	var req a02Req
	err = jsoniter.UnmarshalFromString(params, &req)
	if err != nil || req.Vin == "" {
		return nil, errors.ParamsError
	}

	db := database.DB()

	var res a04Response

	sql := "select * from v_gadm_vin where vin = ? "

	err = db.Raw(sql, req.Vin).Find(&res).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return reply, errors.DataNotExistError
		}
		logger.Error("mysql",
			zap.String("sql", sql),
			zap.String("fields", req.Vin),
			zap.String("error", err.Error()))
		return reply, errors.DataBaseError
	}

	if res.PlateType == "" {
		res.PlateType = calcPlateType(res.Long, res.ApprovedNumber, res.GrossMass)
	}

	if req.PlateType != "" {
		if res.PlateType != "" {
			if req.PlateType == "01" || req.PlateType == "51" {
				if res.PlateType == "02" || res.PlateType == "52" {
					return reply, errors.DataNotExistError
				}
			} else if req.PlateType == "02" || req.PlateType == "52" {
				if res.PlateType == "01" || res.PlateType == "51" {
					return reply, errors.DataNotExistError
				}
			}
		}
		res.PlateType = req.PlateType
	}

	a04Str, _ := jsoniter.MarshalToString(res)
	a04Map := make(map[string]interface{})
	jsoniter.Unmarshal([]byte(a04Str), &a04Map)
	//formatData(a02Map)

	reply.Data, _ = jsoniter.MarshalToString(a04Map)

	return reply, nil

}
