package query

import (
	"context"
	"gd_adm_data/apis"
	"gd_adm_data/model"
	"time"

	jsoniter "github.com/json-iterator/go"

	"gd_adm_data/errors"

	"git.getensh.com/common/gopkgsv2/database"
)

type is01Request struct {
	Vin       string `json:"vin"`
	PlateNo   string `json:"plate_no"`
	PlateType string `json:"plate_type"`
}

type is01Response struct {
	InsuranceFirstDate          string `json:"insurance_first_date"`
	LastCompulsoryInsuranceDate string `json:"last_compulsory_insurance_date"`
	UsePropertyDetail           string `json:"use_property_detail"`
	UpdatedAt                   int64  `json:"updated_at"`
}

// 查首保日期
func IS01(ctx context.Context, params string) (reply *apis.QueryResponse, err error) {
	reply = &apis.QueryResponse{}

	var req is01Request
	err = jsoniter.UnmarshalFromString(params, &req)
	if err != nil {
		return nil, errors.ParamsError
	}

	var res is01Response

	db := database.DB()

	if req.Vin != "" {
		err = db.Raw("select insurance_first_date, updated_at, use_property_detail from t_adm_dws6 where vin = ? ", req.Vin).Find(&res).Error
	} else if req.PlateNo != "" && req.PlateType != "" {
		err = db.Raw("select insurance_first_date, updated_at, use_property_detail from t_adm_dws6 where plate_no = ? and plate_type= ? ", req.PlateNo, req.PlateType).Find(&res).Error
	} else {
		return nil, errors.ParamsError
	}

	list, err := model.NewDws8Model().List(database.DB().Where("vin = ?", req.Vin))

	b := 0
	out := ""
	for _, v := range list {
		if len(v.InsuranceDate) >= 8 {
			c := v.InsuranceDate + " 15:04:05"
			t, _ := time.Parse("2006-01-02 15:04:05", c)
			a := int(t.Unix())
			if a > b {
				b = a
				out = v.InsuranceDate[0:7]
			}
		} else {
			c := v.InsuranceDate + "-01 15:04:05"
			t, _ := time.Parse("2006-01-02 15:04:05", c)
			a := int(t.Unix())
			if a > b {
				b = a
				out = v.InsuranceDate
			}
		}
	}

	if b != 0 {
		res.LastCompulsoryInsuranceDate = out
	} else {
		res.LastCompulsoryInsuranceDate = ""
	}

	if res.InsuranceFirstDate == "" && len(list) == 0 {
		return nil, errors.DataNotExistError
	}

	reply.Data, _ = jsoniter.MarshalToString(res)

	return reply, nil
}
