package query

import (
	"context"

	jsoniter "github.com/json-iterator/go"

	"gd_adm_data/apis"
	"gd_adm_data/errors"
	"gd_adm_data/model"
	"gd_adm_data/utils"

	"git.getensh.com/common/gopkgsv2/database"
	"gorm.io/gorm"
)

type BrandItem struct {
	BrandID       string `json:"brand_id"`
	BrandName     string `json:"brand_name"`
	Logo          string `json:"logo"`
	BrandNamePrex string `json:"brand_name_prex"`
}

type BrandListResponse struct {
	List []BrandItem `json:"list"`
}

func P01(ctx context.Context, params string) (reply *apis.QueryResponse, err error) {
	reply = &apis.QueryResponse{}

	// 构造分页类
	pagination := model.NewPagination(0, 10000, 0).GetLimitOffset()
	list, err := model.NewSyBrand().List(database.DB().Where("status = 1"), pagination)
	if err != nil && err != gorm.ErrRecordNotFound {
		return reply, errors.SystemError
	}

	if err == gorm.ErrRecordNotFound {
		return nil, errors.DataNotExistError
	}

	res := BrandListResponse{
		List: make([]BrandItem, 0, len(list)),
	}
	for _, v := range list {
		res.List = append(res.List, BrandItem{
			BrandID:       v.BrandId,
			BrandName:     v.BrandName,
			Logo:          utils.GetBrandLogoById(v.BrandId, int32(v.HasImg)),
			BrandNamePrex: v.Initial,
		})
	}

	reply.Data, _ = jsoniter.MarshalToString(res)

	return reply, nil
}
