package query

import (
	"context"
	"time"

	jsoniter "github.com/json-iterator/go"

	"gd_adm_data/apis"
	"gd_adm_data/errors"
	"gd_adm_data/model"

	"git.getensh.com/common/gopkgsv2/database"
)

type p06Request struct {
	ExportId string `json:"export_id"`
}

type p06Response struct {
	State int8   `json:"state"`
	Addr  string `json:"addr"`
}

func P06(ctx context.Context, params string) (reply *apis.QueryResponse, err error) {
	reply = &apis.QueryResponse{}

	var req p06Request
	err = jsoniter.UnmarshalFromString(params, &req)
	if err != nil && req.ExportId == "" {
		return nil, errors.ParamsError
	}

	info, err := model.NewExportStyleTaskModel().Get(database.DB().Where("export_id = ?", req.ExportId))
	if err != nil {
		return nil, errors.DataNotExistError
	}

	res := p06Response{
		State: info.Status,
		Addr:  info.Path,
	}

	if info.Status == 0 && time.Now().Unix()-info.CreatedAt.Unix() >= 3600 {
		res.State = 2
	}

	reply.Data, _ = jsoniter.MarshalToString(res)
	return reply, nil
}
